﻿Type=Class
Version=4.5
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
#Event: Finished
#RaisesSynchronousEvents: Anim_Finished_Event

'Class module
Sub Class_Globals
	Private fx As JFX
	Private Anim As JavaObject
	
	Private oModule As Object
	Private sEventName As String
	Private iDurationMs As Double
	Private nNode As Node
	Private iCycleCount As Int = 1
	Private bAutoReverse As Boolean = False
	Private iDelayMs As Double
	Private oTag As Object
	
	'By:
	Private iByX As Double
	Private iByY As Double
	Private iByZ As Double
	
	'From:
	Private iFromX As Double
	Private iFromY As Double
	Private iFromZ As Double

	'To:
	Private iToX As Double
	Private iToY As Double
	Private iToZ As Double
	
End Sub

'Initializes the Transition.
'Module: The module that will receive the events.
'msDuration: The duration of this ScaleTransition (in milliseconds).
'TargetNode: The target node of this ScaleTransition.
'EventName: Name of the event.
Public Sub Initialize(Module As Object, msDuration As Double, TargetNode As Node, EventName As String)
	nNode = TargetNode
	oModule = Module	
	sEventName = EventName
	iDurationMs = msDuration
	
	'Init the animation:
	Anim.InitializeNewInstance("javafx.animation.TranslateTransition", Null)
	Anim.RunMethod("setNode", Array(nNode))
	Anim.RunMethod("setDuration", Array(Duration(iDurationMs)))
	
	'Create the event handler:
	Dim e As JavaObject
	e = Anim.CreateEvent("javafx.event.EventHandler", "Anim_Finished", Null)
	Anim.RunMethod("setOnFinished", Array(e))
End Sub

Private Sub Anim_Finished_Event(MethodName As String, Args() As Object)
	If SubExists(oModule, sEventName & "_Finished") Then
		CallSub(oModule, sEventName & "_Finished")
	End If	
End Sub


#Region Methods:
'Defines whether this Animation reverses direction on alternating cycles.
'If True, the Animation will proceed forward on the first cycle, Then reverses
'on the second cycle, AND so on. Otherwise, animation will Loop such that Each
'cycle proceeds forward from the start. It Is Not possible To change the autoReverse
'flag of a running Animation. If the value of autoReverse Is changed For a running
'Animation, the animation has To be stopped AND started again To pick up the new value.
Public Sub setAutoReverse(Value As Boolean)
	bAutoReverse = Value
	Anim.RunMethod("setAutoReverse", Array(bAutoReverse))
End Sub
Public Sub getAutoReverse As Boolean
	Return bAutoReverse
End Sub	

'Defines the number of cycles in this animation. Must be > 0.
'-1 will play the animation indefinitely
Public Sub setCycleCount(Value As Int)
	iCycleCount = Value
	Anim.RunMethod("setCycleCount", Array(iCycleCount))
End Sub
Public Sub getCycleCount As Int
	Return iCycleCount
End Sub	

'Delays the start of an animation. Cannot be negative. Setting to a negative number will result in IllegalArgumentException.
'(milliseconds).
Public Sub setDelay(Millis As Double)
	iDelayMs = Millis
	Anim.RunMethod("setDelay", Array(Duration(iDelayMs)))
End Sub
Public Sub getDelay As Double
	Return iDelayMs	
End Sub

'Starts playing the animation.
Public Sub Play
	Anim.RunMethod("play", Null)
End Sub	

'Pauses the animation. If the animation is not currently running, this method has no effect.
'Note:
'pause() Is an asynchronous call, the Animation may Not pause immediately.
Public Sub Pause
	Anim.RunMethod("pause", Null)
End Sub	

'Stops the animation and resets the play head to its initial position. If the animation is not currently running, this method has no effect.
'Note:
'stop() Is an asynchronous call, the Animation may Not stop immediately.
Public Sub Stop
	Anim.RunMethod("stop", Null)
End Sub	

'Set the tag of the animation:
Public Sub setTag(Value As Object)
	oTag = Value
End Sub
Public Sub getTag As Object
	Return oTag
End Sub
#End Region


#Region By:
'Specifies the incremented stop X coordinate value, from the start, of this TranslateTransition.
Public Sub setByX(Value As Double)
	iByX = Value
	Anim.RunMethod("setByX", Array(iByX))
End Sub	
Public Sub getByX As Double
	Return iByX
End Sub	

'Specifies the incremented stop Y coordinate value, from the start, of this TranslateTransition.
Public Sub setByY(Value As Double)
	iByY = Value
	Anim.RunMethod("setByY", Array(iByY))
End Sub	
Public Sub getByY As Double
	Return iByY
End Sub	

'Specifies the incremented stop Z coordinate value, from the start, of this TranslateTransition.
Public Sub setByZ(Value As Double)
	iByZ = Value
	Anim.RunMethod("setByZ", Array(iByZ))
End Sub	
Public Sub getByZ As Double
	Return iByZ
End Sub	
#End Region



#Region From:
'Specifies the start X coordinate value of this TranslateTransition.
Public Sub setFromX(Value As Double)
	iFromX = Value
	Anim.RunMethod("setFromX", Array(iFromX))
End Sub	
Public Sub getFromX As Double
	Return iFromX
End Sub	

'Specifies the start Y coordinate value of this TranslateTransition.
Public Sub setFromY(Value As Double)
	iFromY = Value
	Anim.RunMethod("setFromY", Array(iFromY))
End Sub	
Public Sub getFromY As Double
	Return iFromY
End Sub	

'Specifies the start Z coordinate value of this TranslateTransition.
Public Sub setFromZ(Value As Double)
	iFromZ = Value
	Anim.RunMethod("setFromZ", Array(iFromZ))
End Sub	
Public Sub getFromZ As Double
	Return iFromZ
End Sub	
#End Region



#Region To:
'Specifies the stop X coordinate value of this TranslateTransition.
Public Sub setToX(Value As Double)
	iToX = Value
	Anim.RunMethod("setToX", Array(iToX))
End Sub	
Public Sub getToX As Double
	Return iToX
End Sub	

'Specifies the stop Y coordinate value of this TranslateTransition.
Public Sub setToY(Value As Double)
	iToY = Value
	Anim.RunMethod("setToY", Array(iToY))
End Sub	
Public Sub getToY As Double
	Return iToY
End Sub	

'Specifies the stop Z coordinate value of this TranslateTransition.
Public Sub setToZ(Value As Double)
	iToZ = Value
	Anim.RunMethod("setToZ", Array(iToZ))
End Sub	
Public Sub getToZ As Double
	Return iToZ
End Sub	
#End Region



Private Sub Duration(millis As Double) As Object
	Dim DurationJo As JavaObject
	DurationJo.InitializeStatic("javafx.util.Duration")
	Return DurationJo.RunMethod("millis", Array(millis))
End Sub	